/*
 * Copyright (c) 2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __TIME_H
#define __TIME_H

#include <jeffpc/types.h>
#include <jeffpc/time.h>

enum time_parts {
	TIME_PART_DATE =	0x01, /* year, month, day */
	TIME_PART_TIME_HM =	0x02, /* hours, minutes */
	TIME_PART_TIME_S =	0x04, /* seconds */
#define TIME_PART_TIME_HMS	(TIME_PART_TIME_HM | TIME_PART_TIME_S)
};

struct time {
	uint16_t year;	/* 0-65535 */
	uint8_t month;	/* 1-12 */
	uint8_t day;	/* 1-31 */
	uint8_t hour;	/* 0-23 */
	uint8_t min;	/* 0-59 */
	uint8_t sec;	/* 0-60 */
	enum time_parts have:8;
};

extern int time_cmp(const struct time *a, const struct time *b);

/*
 * These print date/time and return true if the struct time contains
 * date/time, otherwise they fill in question marks and return false.
 */
extern bool time_snprint_date(char *buf, size_t bufsize, const struct time *t);
extern bool time_snprint_time(char *buf, size_t bufsize, const struct time *t);

#endif
