/*
 * Copyright (c) 2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __UTIL_H
#define __UTIL_H

#include <ctype.h>

#include <jeffpc/types.h>

extern int extract_float_as_int64(const char *input, unsigned int scale,
				  int64_t *result_r);
extern int extract_float_as_int32(const char *input, unsigned int scale,
				  int32_t *result_r);
extern int extract_float_as_double(const char *input, double *result_r);

extern bool valid_date(uint32_t y, uint32_t m, uint32_t d);

extern char *trim_ws(char *str);

static inline void uppercase_inplace(char *str)
{
	for (; str && *str; str++)
		*str = toupper(*str);
}

static inline void lowercase_inplace(char *str)
{
	for (; str && *str; str++)
		*str = tolower(*str);
}

/* find first non-whitespace character from the beginning */
static inline char *find_nonws(char *str)
{
	while (str && *str && isspace(*str))
		str++;

	return str;
}

/* find first non-whitespace character from the end */
static inline char *rfind_nonws(char *str)
{
	char *end;
	char *ptr;

	if (!str)
		return NULL;

	end = str + strlen(str);
	ptr = end - 1;

	while ((ptr >= str) && isspace(*ptr))
		ptr--;

	return (ptr < str) ? end : ptr;
}

#endif
